@@ -25,48 +25,11 @@ from glance.i18n import _, _LW
 
 
 context_opts = [
-    cfg.BoolOpt('owner_is_tenant', default=True,
-                help=_("""
-Set the image owner to tenant or the authenticated user.
-
-Assign a boolean value to determine the owner of an image. When set to
-True, the owner of the image is the tenant. When set to False, the
-owner of the image will be the authenticated user issuing the request.
-Setting it to False makes the image private to the associated user and
-sharing with other users within the same tenant (or "project")
-requires explicit image sharing via image membership.
-
-Possible values:
-    * True
-    * False
-
-Related options:
-    * None
-
-""")),
-
-    cfg.StrOpt('admin_role', default='admin',
-               help=_("""
-Role used to identify an authenticated user as administrator.
-
-Provide a string value representing a Keystone role to identify an
-administrative user. Users with this role will be granted
-administrative privileges. The default value for this option is
-'admin'.
-
-Possible values:
-    * A string value which is a valid Keystone role
-
-Related options:
-    * None
-
-""")),
-
     cfg.BoolOpt('allow_anonymous_access', default=False,
                 help=_("""
 Allow limited access to unauthenticated users.
 
-Assign a boolean to determine API access for unathenticated
+Assign a boolean to determine API access for unauthenticated
 users. When set to False, the API cannot be accessed by
 unauthenticated users. When set to True, unauthenticated users can
 access the API with read-only privileges. This however only applies
@@ -110,7 +73,7 @@ class BaseContextMiddleware(wsgi.Middleware):
         try:
             request_id = resp.request.context.request_id
         except AttributeError:
-            LOG.warn(_LW('Unable to retrieve request id from context'))
+            LOG.warning(_LW('Unable to retrieve request id from context'))
         else:
             # For python 3 compatibility need to use bytes type
             prefix = b'req-' if isinstance(request_id, bytes) else 'req-'
@@ -177,7 +140,6 @@ class ContextMiddleware(BaseContextMiddleware):
             return webob.exc.HTTPRequestHeaderFieldsTooLarge(comment=msg)
 
         kwargs = {
-            'owner_is_tenant': CONF.owner_is_tenant,
             'service_catalog': service_catalog,
             'policy_enforcer': self.policy_enforcer,
             'request_id': request_id,
@@ -192,9 +154,6 @@ class ContextMiddleware(BaseContextMiddleware):
         # fixed.
         ctxt.roles = [r.lower() for r in ctxt.roles]
 
-        if CONF.admin_role.strip().lower() in ctxt.roles:
-            ctxt.is_admin = True
-
         return ctxt
 
 
