@@ -22,7 +22,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import importutils
-import six
 
 from glance.common import exception
 from glance.common import timeutils
@@ -259,7 +258,7 @@ class Image(object):
         if self.status == 'active':
             self.status = 'deactivated'
         elif self.status == 'deactivated':
-            # Noop if already deactive
+            # Noop if already deactivate
             pass
         else:
             LOG.debug("Not allowed to deactivate image in status '%s'",
@@ -396,9 +395,9 @@ class Task(object):
     @message.setter
     def message(self, message):
         if message:
-            self._message = six.text_type(message)
+            self._message = str(message)
         else:
-            self._message = six.text_type('')
+            self._message = ''
 
     def _validate_task_status_transition(self, cur_status, new_status):
         valid_transitions = {
@@ -522,7 +521,7 @@ class TaskExecutorFactory(object):
                 if not TaskExecutorFactory.eventlet_deprecation_warned:
                     msg = _LW("The `eventlet` executor has been deprecated. "
                               "Use `taskflow` instead.")
-                    LOG.warn(msg)
+                    LOG.warning(msg)
                     TaskExecutorFactory.eventlet_deprecation_warned = True
                 task_executor = 'taskflow'
 
