@@ -26,12 +26,12 @@ PROJECT_READER = 'role:reader and project_id:%(project_id)s'
 IMAGE_MEMBER_CHECK = 'project_id:%(member_id)s'
 # Check if the visibility of the image supplied in the target matches
 # "community"
-COMMUNITY_VISIBILITY_CHECK = '"community":%(visibility)s'
+COMMUNITY_VISIBILITY_CHECK = "'community':%(visibility)s"
 # Check if the visibility of the resource supplied in the target matches
 # "public"
-PUBLIC_VISIBILITY_CHECK = '"public":%(visibility)s'
+PUBLIC_VISIBILITY_CHECK = "'public':%(visibility)s"
 # Check if the visibility of the image supplied in the target matches "shared"
-SHARED_VISIBILITY_CHECK = '"shared":%(visibility)s'
+SHARED_VISIBILITY_CHECK = "'shared':%(visibility)s"
 
 PROJECT_MEMBER_OR_IMAGE_MEMBER_OR_COMMUNITY_OR_PUBLIC_OR_SHARED = (
     f'role:member and (project_id:%(project_id)s or {IMAGE_MEMBER_CHECK} '
@@ -55,7 +55,7 @@ PROJECT_READER_OR_PUBLIC_NAMESPACE = (
 # These check strings do not support tenancy with the `admin` role. This means
 # anyone with the `admin` role on any project can execute a policy, which is
 # typical in OpenStack services. Eventually, these check strings will be
-# superceded by check strings that implement scope checking and system-scope
+# superseded by check strings that implement scope checking and system-scope
 # for applicable APIs (e.g., making an image public). But, we have a lot of
 # cleanup to do in different parts of glance to sweep all the authorization
 # code into a single layer before we can safely consume system-scope and
@@ -90,6 +90,7 @@ ADMIN_OR_PROJECT_READER_OR_SHARED_MEMBER = (
     f'role:reader and (project_id:%(project_id)s or {IMAGE_MEMBER_CHECK})'
 )
 
+ADMIN = f'role:admin'
 
 rules = [
     policy.RuleDefault(name='default', check_str='',
