@@ -384,9 +384,9 @@ class Scrubber(object):
                                               {'status': 'deleted'})
             LOG.info(_LI("Image %s has been scrubbed successfully"), image_id)
         else:
-            LOG.warn(_LW("One or more image locations couldn't be scrubbed "
-                         "from backend. Leaving image '%s' in 'pending_delete'"
-                         " status"), image_id)
+            LOG.warning(_LW("One or more image locations couldn't be scrubbed "
+                            "from backend. Leaving image '%s' in "
+                            "'pending_delete' status"), image_id)
 
     def _delete_image_location_from_backend(self, image_id, loc_id, uri,
                                             backend=None):
