@@ -15,8 +15,8 @@
 
 """Tests for `glance.wsgi`."""
 
+import http.client as http
 import os
-from six.moves import http_client as http
 import socket
 import time
 
@@ -65,6 +65,10 @@ class TestWSGIServer(functional.FunctionalTest):
 
 
 class StagingCleanupBase:
+    def _configure_api_server(self):
+        self.my_api_server.deployment_flavor = 'noauth'
+        self.my_api_server.send_identity_credentials = True
+
     def _url(self, path):
         return 'http://127.0.0.1:%d%s' % (self.api_port, path)
 
@@ -74,7 +78,7 @@ class StagingCleanupBase:
             'X-Auth-Token': '932c5c84-02ac-4fe5-a9ba-620af0e2bb96',
             'X-User-Id': 'f9a41d13-0c13-47e9-bee2-ce4e8bfe958e',
             'X-Tenant-Id': uuids.tenant1,
-            'X-Roles': 'member',
+            'X-Roles': 'reader,member',
         }
         base_headers.update(custom_headers or {})
         return base_headers
@@ -164,6 +168,7 @@ class TestStagingCleanupMultistore(functional.MultipleBackendFunctionalTest,
     def setUp(self):
         super(TestStagingCleanupMultistore, self).setUp()
         self.my_api_server = self.api_server_multiple_backend
+        self._configure_api_server()
 
 
 class TestStagingCleanupSingleStore(functional.FunctionalTest,
@@ -175,3 +180,4 @@ class TestStagingCleanupSingleStore(functional.FunctionalTest,
     def setUp(self):
         super(TestStagingCleanupSingleStore, self).setUp()
         self.my_api_server = self.api_server
+        self._configure_api_server()
