@@ -44,7 +44,11 @@ class TestImportTask(test_utils.BaseTestCase):
         task_ttl = CONF.task.task_time_to_live
 
         self.task_type = 'import'
+        image_id = 'fake_image_id'
+        user_id = 'fake_user'
+        request_id = 'fake_request_id'
         self.task = self.task_factory.new_task(self.task_type, TENANT1,
+                                               image_id, user_id, request_id,
                                                task_time_to_live=task_ttl,
                                                task_input=task_input)
 
