@@ -14,8 +14,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import http.client as http
+
 from oslo_serialization import jsonutils
-from six.moves import http_client as http
 import webob
 
 from glance.api import authorization
