@@ -21,7 +21,9 @@ import uuid
 from oslo_config import cfg
 from oslo_db import exception as db_exc
 from oslo_utils import encodeutils
+from oslo_utils.fixture import uuidsentinel as uuids
 from oslo_utils import timeutils
+from sqlalchemy import orm as sa_orm
 
 from glance.common import crypt
 from glance.common import exception
@@ -35,33 +37,6 @@ CONF = cfg.CONF
 CONF.import_opt('metadata_encryption_key', 'glance.common.config')
 
 
-@mock.patch('oslo_utils.importutils.import_module')
-class TestDbUtilities(test_utils.BaseTestCase):
-    def setUp(self):
-        super(TestDbUtilities, self).setUp()
-        self.config(data_api='silly pants')
-        self.api = mock.Mock()
-
-    def test_get_api_calls_configure_if_present(self, import_module):
-        import_module.return_value = self.api
-        self.assertEqual(glance.db.get_api(), self.api)
-        import_module.assert_called_once_with('silly pants')
-        self.api.configure.assert_called_once_with()
-
-    def test_get_api_skips_configure_if_missing(self, import_module):
-        import_module.return_value = self.api
-        del self.api.configure
-        self.assertEqual(glance.db.get_api(), self.api)
-        import_module.assert_called_once_with('silly pants')
-        self.assertFalse(hasattr(self.api, 'configure'))
-
-    def test_get_api_calls_for_v1_api(self, import_module):
-        api = glance.db.get_api(v1_mode=True)
-        self.assertNotEqual(api, self.api)
-        import_module.assert_called_once_with('glance.db.sqlalchemy.api')
-        api.configure.assert_called_once_with()
-
-
 UUID1 = 'c80a1a6c-bd1f-41c5-90ee-81afedb1d58d'
 UUID2 = 'a85abd86-55b3-4d5b-b0b4-5d0a6e6042fc'
 UUID3 = '971ec09a-8067-4bc8-a91f-ae3557f1c4c7'
@@ -82,6 +57,11 @@ CHECKSUM = '93264c3edf5972c9f1cb309543d38a5c'
 CHCKSUM1 = '43264c3edf4972c9f1cb309543d38a55'
 
 
+TASK_ID_1 = 'b3006bd0-461e-4228-88ea-431c14e918b4'
+TASK_ID_2 = '07b6b562-6770-4c8b-a649-37a515144ce9'
+TASK_ID_3 = '72d16bb6-4d70-48a5-83fe-14bb842dc737'
+
+
 def _db_fixture(id, **kwargs):
     obj = {
         'id': id,
@@ -116,17 +96,24 @@ def _db_image_member_fixture(image_id, member_id, **kwargs):
     return obj
 
 
-def _db_task_fixture(task_id, type, status, **kwargs):
+def _db_task_fixture(task_id, **kwargs):
+    default_datetime = timeutils.utcnow()
     obj = {
         'id': task_id,
-        'type': type,
-        'status': status,
-        'input': None,
+        'status': kwargs.get('status', 'pending'),
+        'type': 'import',
+        'input': kwargs.get('input', {}),
         'result': None,
         'owner': None,
+        'image_id': kwargs.get('image_id'),
+        'user_id': kwargs.get('user_id'),
+        'request_id': kwargs.get('request_id'),
         'message': None,
-        'deleted': False,
-        'expires_at': timeutils.utcnow() + datetime.timedelta(days=365)
+        'expires_at': default_datetime + datetime.timedelta(days=365),
+        'created_at': default_datetime,
+        'updated_at': default_datetime,
+        'deleted_at': None,
+        'deleted': False
     }
     obj.update(kwargs)
     return obj
@@ -163,6 +150,53 @@ class TestImageRepo(test_utils.BaseTestCase):
         ]
         [self.db.image_create(None, image) for image in self.images]
 
+        # Create tasks associated with image
+        self.tasks = [
+            _db_task_fixture(
+                TASK_ID_1, image_id=UUID1, status='completed',
+                input={
+                    "image_id": UUID1,
+                    "import_req": {
+                        "method": {
+                            "name": "glance-direct"
+                        },
+                        "backend": ["fake-store"]
+                    },
+                },
+                user_id=USER1,
+                request_id='fake-request-id',
+            ),
+            _db_task_fixture(
+                TASK_ID_2, image_id=UUID1, status='completed',
+                input={
+                    "image_id": UUID1,
+                    "import_req": {
+                        "method": {
+                            "name": "copy-image"
+                        },
+                        "all_stores": True,
+                        "all_stores_must_succeed": False,
+                        "backend": ["fake-store", "fake_store_1"]
+                    },
+                },
+                user_id=USER1,
+                request_id='fake-request-id',
+            ),
+            _db_task_fixture(
+                TASK_ID_3, status='completed',
+                input={
+                    "image_id": UUID2,
+                    "import_req": {
+                        "method": {
+                            "name": "glance-direct"
+                        },
+                        "backend": ["fake-store"]
+                    },
+                },
+            ),
+        ]
+        [self.db.task_create(None, task) for task in self.tasks]
+
         self.db.image_tag_set_all(None, UUID1, ['ping', 'pong'])
 
     def _create_image_members(self):
@@ -183,6 +217,18 @@ class TestImageRepo(test_utils.BaseTestCase):
         self.assertEqual(256, image.size)
         self.assertEqual(TENANT1, image.owner)
 
+    def test_tasks_get_by_image(self):
+        tasks = self.db.tasks_get_by_image(self.context, UUID1)
+        self.assertEqual(2, len(tasks))
+        for task in tasks:
+            self.assertEqual(USER1, task['user_id'])
+            self.assertEqual('fake-request-id', task['request_id'])
+            self.assertEqual(UUID1, task['image_id'])
+
+    def test_tasks_get_by_image_not_exists(self):
+        tasks = self.db.tasks_get_by_image(self.context, UUID3)
+        self.assertEqual(0, len(tasks))
+
     def test_location_value(self):
         image = self.image_repo.get(UUID3)
         self.assertEqual(UUID3_LOCATION, image.locations[0]['url'])
@@ -264,6 +310,27 @@ class TestImageRepo(test_utils.BaseTestCase):
         image_ids = set([i.image_id for i in images])
         self.assertEqual(set([UUID2]), image_ids)
 
+    def test_list_shared_images_other_tenant(self):
+        # Create a private image owned by TENANT3
+        image5 = _db_fixture(uuids.image5, owner=TENANT3,
+                             name='5', size=512, is_public=False)
+        self.db.image_create(None, image5)
+
+        # Get a repo as TENANT3, since it has access to public,
+        # shared, and private images
+        context = glance.context.RequestContext(user=USER1, tenant=TENANT3)
+        image_repo = glance.db.ImageRepo(context, self.db)
+        images = {i.image_id: i for i in image_repo.list()}
+
+        # No member set for public image UUID1
+        self.assertIsNone(images[UUID1].member)
+
+        # Member should be set to our tenant id for shared image UUID2
+        self.assertEqual(TENANT3, images[UUID2].member)
+
+        # No member set for private image5
+        self.assertIsNone(images[uuids.image5].member)
+
     def test_list_all_images(self):
         filters = {'visibility': 'all'}
         images = self.image_repo.list(filters=filters)
@@ -827,13 +894,20 @@ class TestTaskRepo(test_utils.BaseTestCase):
 
     def test_add_task(self):
         task_type = 'import'
-        task = self.task_factory.new_task(task_type, None,
+        image_id = 'fake_image_id'
+        user_id = 'fake_user'
+        request_id = 'fake_request_id'
+        task = self.task_factory.new_task(task_type, None, image_id,
+                                          user_id, request_id,
                                           task_input=self.fake_task_input)
         self.assertEqual(task.updated_at, task.created_at)
         self.task_repo.add(task)
         retrieved_task = self.task_repo.get(task.task_id)
         self.assertEqual(task.updated_at, retrieved_task.updated_at)
         self.assertEqual(self.fake_task_input, retrieved_task.task_input)
+        self.assertEqual(image_id, task.image_id)
+        self.assertEqual(user_id, task.user_id)
+        self.assertEqual(request_id, task.request_id)
 
     def test_save_task(self):
         task = self.task_repo.get(UUID1)
@@ -887,3 +961,39 @@ class RetryOnDeadlockTestCase(test_utils.BaseTestCase):
                 api.image_destroy(None, 'fake-id')
             except TestException:
                 self.assertEqual(3, sess.call_count)
+
+
+class TestImageDeleteRace(test_utils.BaseTestCase):
+
+    @mock.patch.object(api, 'LOG')
+    def test_image_property_delete_stale_data(self, mock_LOG):
+        mock_context = mock.MagicMock()
+        mock_session = mock.MagicMock()
+        mock_result = (mock_session.query.return_value.
+                       filter_by.return_value.
+                       one.return_value)
+        mock_result.delete.side_effect = sa_orm.exc.StaleDataError('myerror')
+        # StaleDataError should not be raised
+        r = api.image_property_delete(mock_context, 'myprop', 'myimage',
+                                      session=mock_session)
+        # We should not get the property back
+        self.assertIsNone(r)
+        # Make sure we logged it
+        mock_LOG.debug.assert_called_once_with(
+            'StaleDataError while deleting property %(prop)r '
+            'from image %(image)r likely means we raced during delete: '
+            '%(err)s', {'prop': 'myprop', 'image': 'myimage',
+                        'err': 'myerror'})
+
+    def test_image_property_delete_exception(self):
+        mock_context = mock.MagicMock()
+        mock_session = mock.MagicMock()
+        mock_result = (mock_session.query.return_value.
+                       filter_by.return_value.
+                       one.return_value)
+        mock_result.delete.side_effect = RuntimeError
+        # Any other exception should be raised
+        self.assertRaises(RuntimeError,
+                          api.image_property_delete,
+                          mock_context, 'myprop', 'myimage',
+                          session=mock_session)
