@@ -14,9 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
+from unittest import mock
 
 from glance.domain import proxy
 import glance.tests.utils as test_utils
@@ -49,6 +47,8 @@ class FakeRepo(object):
     add = fake_method
     save = fake_method
     remove = fake_method
+    set_property_atomic = fake_method
+    delete_property_atomic = fake_method
 
 
 class TestProxyRepoPlain(test_utils.BaseTestCase):
@@ -80,6 +80,28 @@ class TestProxyRepoPlain(test_utils.BaseTestCase):
     def test_remove(self):
         self._test_method('add', None, 'flying')
 
+    def test_set_property_atomic(self):
+        image = mock.MagicMock()
+        image.image_id = 'foo'
+        self._test_method('set_property_atomic', None, image, 'foo', 'bar')
+
+    def test_set_property_nonimage(self):
+        self.assertRaises(
+            AssertionError,
+            self._test_method,
+            'set_property_atomic', None, 'notimage', 'foo', 'bar')
+
+    def test_delete_property_atomic(self):
+        image = mock.MagicMock()
+        image.image_id = 'foo'
+        self._test_method('delete_property_atomic', None, image, 'foo', 'bar')
+
+    def test_delete_property_nonimage(self):
+        self.assertRaises(
+            AssertionError,
+            self._test_method,
+            'delete_property_atomic', None, 'notimage', 'foo', 'bar')
+
 
 class TestProxyRepoWrapping(test_utils.BaseTestCase):
     def setUp(self):
