@@ -96,6 +96,7 @@ class ImageStub(object):
         self.virtual_size = 0
         self.tags = []
         self.os_hidden = os_hidden
+        self.member = self.owner
 
     def delete(self):
         self.status = 'deleted'
@@ -238,7 +239,7 @@ class MdTagRepoStub(object):
     def add(self, tag):
         return 'mdtag_add'
 
-    def add_tags(self, tags):
+    def add_tags(self, tags, can_append=False):
         return ['mdtag_add_tags']
 
     def get(self, ns, tag_name):
@@ -257,7 +258,8 @@ class MdTagRepoStub(object):
 class TestPolicyEnforcer(base.IsolatedUnitTest):
 
     def test_policy_enforce_unregistered(self):
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
         context = glance.context.RequestContext(roles=[])
 
         self.assertRaises(glance.api.policy.policy.PolicyNotRegistered,
@@ -265,7 +267,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
                           context, 'wibble', {})
 
     def test_policy_check_unregistered(self):
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
         context = glance.context.RequestContext(roles=[])
 
         self.assertRaises(glance.api.policy.policy.PolicyNotRegistered,
@@ -273,16 +276,19 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
                           context, 'wibble', {})
 
     def test_policy_file_default_rules_default_location(self):
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
-        context = glance.context.RequestContext(roles=[])
-        enforcer.enforce(context, 'get_image', {})
+        context = glance.context.RequestContext(roles=['reader'])
+        enforcer.enforce(context, 'get_image',
+                         {'project_id': context.project_id})
 
     def test_policy_file_custom_rules_default_location(self):
         rules = {"get_image": '!'}
         self.set_policy_rules(rules)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertRaises(exception.Forbidden,
@@ -295,7 +301,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         rules = {"get_image": '!'}
         self.set_policy_rules(rules)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertRaises(exception.Forbidden,
@@ -308,7 +315,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         rules = {"get_image": '!'}
         self.set_policy_rules(rules)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertEqual(False, enforcer.check(context, 'get_image', {}))
@@ -317,7 +325,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         rules = {"default": ''}
         self.set_policy_rules(rules)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertEqual(True, enforcer.check(context, 'get_image', {}))
@@ -326,7 +335,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         rules = {"default": '!'}
         self.set_policy_rules(rules)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertRaises(exception.Forbidden,
@@ -337,7 +347,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         rule = common_policy.RuleDefault(
             name=policy_name, check_str='role:bar', scope_types=['system'])
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
         enforcer.register_default(rule)
 
         context = glance.context.RequestContext(
@@ -366,7 +377,8 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
         context = glance.context.RequestContext()
         mock_enforcer = self.mock_object(common_policy.Enforcer, 'enforce')
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
         enforcer.register_default(
             common_policy.RuleDefault(name='foo', check_str='role:bar')
         )
@@ -395,13 +407,15 @@ class TestPolicyEnforcer(base.IsolatedUnitTest):
             "personas, specifically for system-scope."
         )
         with mock.patch.object(glance.api.policy, 'LOG') as mock_log:
-            glance.api.policy.Enforcer()
+            glance.api.policy.Enforcer(
+                suppress_deprecation_warnings=True)
             mock_log.warning.assert_called_once_with(expected_log_string)
 
     def test_ensure_experimental_warning_is_not_logged_for_legacy_rbac(self):
         self.config(enforce_new_defaults=False, group='oslo_policy')
         with mock.patch.object(glance.api.policy, 'LOG') as mock_log:
-            glance.api.policy.Enforcer()
+            glance.api.policy.Enforcer(
+                suppress_deprecation_warnings=True)
             mock_log.warning.assert_not_called()
 
 
@@ -411,7 +425,8 @@ class TestPolicyEnforcerNoFile(base.IsolatedUnitTest):
         """Missing defined policy file should result in a default ruleset"""
         self.config(policy_file='gobble.gobble', group='oslo_policy')
         self.config(enforce_new_defaults=True, group='oslo_policy')
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertRaises(exception.Forbidden,
@@ -431,7 +446,8 @@ class TestPolicyEnforcerNoFile(base.IsolatedUnitTest):
         self.mock_object(oslo_config.cfg.ConfigOpts, 'find_file',
                          fake_find_file)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[])
         self.assertRaises(exception.Forbidden,
@@ -1027,7 +1043,8 @@ class TestContextPolicyEnforcer(base.IsolatedUnitTest):
         rules = {'context_is_admin': 'role:%s' % policy_admin_role}
         self.set_policy_rules(rules)
 
-        enforcer = glance.api.policy.Enforcer()
+        enforcer = glance.api.policy.Enforcer(
+            suppress_deprecation_warnings=True)
 
         context = glance.context.RequestContext(roles=[context_role],
                                                 is_admin=context_is_admin,
@@ -1071,13 +1088,14 @@ class TestDefaultPolicyCheckStrings(base.IsolatedUnitTest):
 
     def test_project_member_download_image_check_string(self):
         expected = (
-            'role:member and (project_id:%(project_id)s or '
-            'project_id:%(member_id)s or "community":%(visibility)s or '
-            '"public":%(visibility)s)'
+            "role:member and (project_id:%(project_id)s or "
+            "project_id:%(member_id)s or 'community':%(visibility)s or "
+            "'public':%(visibility)s or 'shared':%(visibility)s)"
         )
         self.assertEqual(
             expected,
-            base_policy.PROJECT_MEMBER_OR_IMAGE_MEMBER_OR_COMMUNITY_OR_PUBLIC
+            base_policy.
+            PROJECT_MEMBER_OR_IMAGE_MEMBER_OR_COMMUNITY_OR_PUBLIC_OR_SHARED
         )
 
     def test_project_reader_check_string(self):
@@ -1090,13 +1108,14 @@ class TestDefaultPolicyCheckStrings(base.IsolatedUnitTest):
 
     def test_project_reader_get_image_check_string(self):
         expected = (
-            'role:reader and (project_id:%(project_id)s or '
-            'project_id:%(member_id)s or "community":%(visibility)s or '
-            '"public":%(visibility)s)'
+            "role:reader and (project_id:%(project_id)s or "
+            "project_id:%(member_id)s or \'community\':%(visibility)s or "
+            "'public':%(visibility)s or 'shared':%(visibility)s)"
         )
         self.assertEqual(
             expected,
-            base_policy.PROJECT_READER_OR_IMAGE_MEMBER_OR_COMMUNITY_OR_PUBLIC
+            base_policy.
+            PROJECT_READER_OR_IMAGE_MEMBER_OR_COMMUNITY_OR_PUBLIC_OR_SHARED
         )
 
 
@@ -1105,3 +1124,28 @@ class TestImageTarget(base.IsolatedUnitTest):
         image = ImageStub()
         target = glance.api.policy.ImageTarget(image)
         self.assertNotIn('locations', list(target))
+
+    def test_image_target_project_id_alias(self):
+        image = ImageStub()
+        target = glance.api.policy.ImageTarget(image)
+        self.assertIn('project_id', target)
+        self.assertEqual(image.owner, target['project_id'])
+        self.assertEqual(image.owner, target['owner'])
+
+    def test_image_target_transforms(self):
+        fake_image = mock.MagicMock()
+        fake_image.image_id = mock.sentinel.image_id
+        fake_image.owner = mock.sentinel.owner
+        fake_image.member = mock.sentinel.member
+
+        target = glance.api.policy.ImageTarget(fake_image)
+
+        # Make sure the key transforms work
+        self.assertEqual(mock.sentinel.image_id, target['id'])
+        self.assertEqual(mock.sentinel.owner, target['project_id'])
+        self.assertEqual(mock.sentinel.member, target['member_id'])
+
+        # Also make sure the base properties still work
+        self.assertEqual(mock.sentinel.image_id, target['image_id'])
+        self.assertEqual(mock.sentinel.owner, target['owner'])
+        self.assertEqual(mock.sentinel.member, target['member'])
