@@ -17,9 +17,9 @@
 from cryptography import exceptions as crypto_exception
 import glance_store as store
 from unittest import mock
+import urllib
 
 from oslo_config import cfg
-from six.moves import urllib
 
 from glance.common import exception
 from glance.common import store_utils
@@ -64,12 +64,16 @@ def sort_url_by_qs_keys(url):
 
 
 def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
-                     roles=None, tenant=TENANT1):
+                     roles=None, headers=None, tenant=TENANT1):
     if roles is None:
-        roles = ['member']
+        roles = ['member', 'reader']
 
     req = wsgi.Request.blank(path)
     req.method = method
+    req.headers = {'x-openstack-request-id': 'my-req'}
+
+    if headers is not None:
+        req.headers.update(headers)
 
     kwargs = {
         'user': user,
@@ -270,6 +274,20 @@ class FakeStoreAPI(object):
         pass
 
 
+class FakeStoreAPIReader(FakeStoreAPI):
+    """A store API that actually reads from the data pipe."""
+
+    def add_to_backend_with_multihash(self, conf, image_id, data, size,
+                                      hashing_algo, scheme=None, context=None,
+                                      verifier=None):
+        for chunk in data:
+            pass
+
+        return super(FakeStoreAPIReader, self).add_to_backend_with_multihash(
+            conf, image_id, data, size, hashing_algo,
+            scheme=scheme, context=context, verifier=verifier)
+
+
 class FakePolicyEnforcer(object):
     def __init__(self, *_args, **kwargs):
         self.rules = {}
