@@ -15,14 +15,12 @@
 #    under the License.
 
 import datetime
+import http.client as http
 from unittest import mock
 import uuid
 
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-from six.moves import http_client as http
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
 import webob
 
 import glance.api.v2.tasks
